function PnP_mRound(%val)
{
	if (%val <= 0)
		return mCeil(%val-0.5);
	else
		return mFloor(%val+0.5);
}

//brick shift vector functions
//x/y shift vectors must be in multiples of .5, and .2 for z

function PnP_roundShiftVector(%vector)
{
	%x = getWord(%vector, 0)*2;
	%y = getWord(%vector, 1)*2;
	%z = getWord(%vector, 2)*5;

	return PnP_mRound(%x)/2 SPC PnP_mRound(%y)/2 SPC PnP_mRound(%z)/5;
}

function roundToNearestFifth(%val)
{
	return PnP_mRound(%val*5)/5;
}

function PnP_mRoundDecimal(%val)
{
	if (%val*10 <= 0)
		return mCeil(%val*10-0.5)/10;
	else
		return mFloor(%val*10+0.5)/10;
}

function PnP_roundVector(%vector)
{
	//rounds vectors to the nearest .1
	%x = getWord(%vector, 0);
	%y = getWord(%vector, 1);
	%z = getWord(%vector, 2);

	return PnP_mRoundDecimal(%x) SPC PnP_mRoundDecimal(%y) SPC PnP_mRoundDecimal(%z);
}

function PnP_roundVectorNearestHalf(%vector)
{
	//rounds vectors to the nearest .5
	%x = getWord(%vector, 0)*2;
	%y = getWord(%vector, 1)*2;
	%z = getWord(%vector, 2)*2;

	return PnP_mRound(%x)/2 SPC PnP_mRound(%y)/2 SPC PnP_mRound(%z)/2;
}

function getZPosBound(%brick)
{
	//Returns the elevation of the lowest edge of %brick
	return getWord(%brick.getPosition(), 2) - %brick.getDataBlock().brickSizeZ/10;
}

function getBottomCornerPos(%brick)
{
	//Returns the coordinates of the bottom corner of %brick (to scale the positions of all the bricks with)
	if (%brick.getAngleID()%2)
	{
		%xpos = getWord(%brick.getPosition(), 0) - %brick.getDataBlock().brickSizeY/4;
		%ypos = getWord(%brick.getPosition(), 1) - %brick.getDataBlock().brickSizeX/4;
		%zpos = getZPosBound(%brick);
		%xyzpos = %xpos SPC %ypos SPC %zpos;
	}
	else
	{
		%xpos = getWord(%brick.getPosition(), 0) - %brick.getDataBlock().brickSizeX/4;
		%ypos = getWord(%brick.getPosition(), 1) - %brick.getDataBlock().brickSizeY/4;
		%zpos = getZPosBound(%brick);
		%xyzpos = %xpos SPC %ypos SPC %zpos;
	}

	return %xyzpos;
}

function isInteger(%val)
{
	return stripChars(%val, "1234567890") $= "";
}

function isDouble(%val)
{
	if (stripChars(%val, "1234567890") $= "")
		return stripos(%val, ".", stripos(%val, ".")+1) < 0;
}