function PnPapplyProperties(%brick, %line, %angleID)
{
	if (getWord(%line, 0) $= "+-EVENT")
		PnPapplyEvent(%brick, %line, %angleID);
	if (getWord(%line, 0) $= "+-LIGHT")
		PnPapplyLight(%brick, %line);
	if (getWord(%line, 0) $= "+-ITEM")
		PnPapplyItem(%brick, %line, %angleID);
	if (getWord(%line, 0) $= "+-EMITTER")
		PnPapplyEmitter(%brick, %line, %angleID);
}

function PnPapplyItem(%brick, %line, %angleID)
{
	//takes in a %brick and a %line from a save file (including the +- prefix)
	//and applies the line's item onto the brick
	%line = restWords(%line);
	%itemNameEnd = stripos(%line, "\"");
	%itemName = getSubStr(%line, 0, %itemNameEnd);
	%line = getSubStr(%line, %itemNameEnd+2, strlen(%line)-%itemNameEnd-1);
	%itemPos = getWord(%line, 0);
	if (%itemPos > 1)
		%itemPos = 2+(%itemPos-2+%angleID)%4;
	%itemDir = 2+(getWord(%line, 1)-2 + %angleID)%4;
	%itemTimeout = getWord(%line, 2);

	%brick.setItem($uiNameTable_Items[%itemName]);
	%brick.setItemDirection(%itemDir);
	%brick.setItemPosition(%itemPos);
	%brick.setItemRespawnTime(%itemTimeout);
}

function PnPapplyEmitter(%brick, %line, %angleID)
{
	//takes in a %brick and a %line from a save file (including the +- prefix)
	//and applies the line's emitter onto the brick
	%line = restWords(%line);
	%emitterNameEnd = stripos(%line, "\"");
	%emitterName = getSubStr(%line, 0, %emitterNameEnd);
	%line = getSubStr(%line, %emitterNameEnd+2, strlen(%line)-%emitterNameEnd-1);
	%emitterDir = getWord(%line, 0);
	if (%emitterDir > 1)
		%emitterDir = 2+(%emitterDir-2+%angleID)%4;

	%brick.setemitter($uiNameTable_emitters[%emitterName]);
	%brick.setemitterDirection(%emitterDir);
}

function PnPapplyLight(%brick, %line)
{
	%line = restWords(%line);
	%lightNameEnd = stripos(%line, "\"");
	%light = getSubStr(%line, 0, %lightNameEnd);
	if ($uiNameTable_Lights[%light] > 0)
		%brick.setLight($uiNameTable_Lights[%light]);
}

function PnPapplyEvent(%brick, %line, %angleID)
{
	%idx = getField(%line, "1");
    %enabled = getField(%line, "2");
    %inputName = getField(%line, "3");
    %delay = getField(%line, "4");
    %targetName = getField(%line, "5");
    %NT = getField(%line, "6");
    %outputName = getField(%line, "7");
    %par1 = getField(%line, "8");
    %par2 = getField(%line, "9");
    %par3 = getField(%line, "10");
    %par4 = getField(%line, "11");
    if (isObject(%par1) && !isInteger(%par1) && getWordCount(%par1) == 1)
    	%par1 = nameToID(%par1);
    if (isObject(%par2) && !isInteger(%par2) && getWordCount(%par2) == 1)
    	%par2 = nameToID(%par2);
    if (isObject(%par3) && !isInteger(%par3) && getWordCount(%par3) == 1)
    	%par3 = nameToID(%par3);
    if (isObject(%par4) && !isInteger(%par4) && getWordCount(%par4) == 1)
    	%par4 = nameToID(%par4);

    %inputEventIdx = inputEvent_GetInputEventIdx(%inputName);
    %targetIdx = inputEvent_GetTargetIndex("fxDTSBrick", %inputEventIdx, %targetName);
    
    if(%targetName == (-1))
        %targetClass = "fxDTSBrick";
	else
	{
		%field = getField($InputEvent_TargetList["fxDTSBrick", %inputEventIdx], %targetIdx);
		%targetClass = getWord(%field, "1");
	}
    %outputEventIdx = outputEvent_GetOutputEventIdx(%targetClass, %outputName);
    %NTNameIdx = (-1);
	
	//check for rotation
	//check for vector parameters
	%paramList = $OutputEvent_ParameterList[%targetClass, %outputEventIdx];
	%paramCount = getFieldCount(%paramList);
	for(%k = 0; %k < %paramCount; %k++)
	{
		if(getWord(getField(%paramList, %k), 0) $= "vector")
		{
			//apply rotation effects
			%vec = %par[%k+1];

			for (%i = 0; %i < 4-%angleID; %i++)
				%vec = -getWord(%vec, 1) SPC getWord(%vec, 0) SPC getWord(%vec, 2);

			%par[%k+1] = %vec;
		}
	}
	//check for relay events
	switch$(%outputName)
	{
		case "fireRelayNorth": %dir = 2;
		case "fireRelayEast":  %dir = 3;
		case "fireRelaySouth": %dir = 4;
		case "fireRelayWest":  %dir = 5;
		default: %dir = -1;
	}
	if(%dir >= 0)
	{
		%rotated = %dir;
		%rotated = (%rotated + %angleID - 2) % 4 + 2;
		//Apply mirror effects
		%outputEventIdx += %rotated - %dir;

		switch(%rotated)
		{
			case 0: %outputName = "fireRelayUp";
			case 1: %outputName = "fireRelayDown";
			case 2: %outputName = "fireRelayNorth";
			case 3: %outputName = "fireRelayEast";
			case 4: %outputName = "fireRelaySouth";
			case 5: %outputName = "fireRelayWest";
		}
	}
    //talk(%brick SPC %enabled SPC %inputEventIdx SPC %delay SPC %targetName SPC %targetIDX SPC %NTNameIdx SPC %outputName SPC %outputEventIdx SPC %par1 SPC %par2 SPC %par3 SPC %par4);
    //talk(%targetClass @ %outputName);
    //talk(%NT);

    %brick.eventEnabled[%idx] = %enabled;
	%brick.eventInput[%idx] = %inputName;
	%brick.eventInputIdx[%idx] = %inputEventIdx;
	%brick.eventDelay[%idx] = %delay;
	%brick.eventTarget[%idx] = %targetName;
	%brick.eventTargetIDX[%idx] = %targetIdx;
	if (%NT !$= "")
		%brick.eventNT[%idx] = %NT;
	%brick.eventOutput[%idx] = %outputName;
	%brick.eventOutputIdx[%idx] = %outputEventIdx;
	if (%par1 !$= "")
		%brick.eventOutputParameter[%idx,1] = %par1;
	if (%par2 !$= "")
		%brick.eventOutputParameter[%idx,2] = %par2;
	if (%par3 !$= "")
		%brick.eventOutputParameter[%idx,3] = %par3;
	if (%par4 !$= "")
		%brick.eventOutputParameter[%idx,4] = %par4;
	%brick.eventOutputAppendClient[%idx] = $outputEvent_AppendClient[%targetName, %eventOutputIdx]; //fix this asap
	%brick.numEvents = %idx+1;
}